@@ -21,8 +21,8 @@ use Exporter;
 
 ## ----------------------------------------------------------------------
 ## get command line options
-use vars qw( $opt_L $opt_P $opt_b $opt_c $opt_C $opt_e $opt_f $opt_l $opt_m $opt_t $opt_1 $opt_x $opt_X);
-getopts( 'LPb:cCe:f:l:mt:1xX:' );
+use vars qw( $opt_L $opt_P $opt_b $opt_c $opt_C $opt_e $opt_f $opt_l $opt_m $opt_t $opt_1 $opt_x $opt_X $opt_S);
+getopts( 'LPb:cCe:f:l:mt:1xX:S' );
 
 ## ----------------------------------------------------------------------
 ## import packages
@@ -753,23 +753,27 @@ sub end_var
 ## ----------------------------------------------------------------------
 sub start_package
 {
+    $is_example = 1;
     push_output( 'string' );
 }
 sub end_package
 {
     $_ = _trim( pop_output );
     &{$Format."::"._output_package}( $_ ) if length( $_ );
+    $is_example = 0;
 }
 
 ## ----------------------------------------------------------------------
 sub start_prgn
 {
+    $is_example = 1;
     push_output( 'string' );
 }
 sub end_prgn
 {
     $_ = _trim( pop_output );
     &{$Format."::"._output_prgn}( $_ ) if length( $_ );
+    $is_example = 0;
 }
 
 ## ----------------------------------------------------------------------
@@ -788,12 +792,14 @@ sub end_file
 ## ----------------------------------------------------------------------
 sub start_tt
 {
+    $is_example = 1;
     push_output( 'string' );
 }
 sub end_tt
 {
     $_ = _trim( pop_output );
     &{$Format."::"._output_tt}( $_ ) if length( $_ );
+    $is_example = 0;
 }
 
 ## ----------------------------------------------------------------------
