@@ -166,7 +166,7 @@ sub _output_end_book
 	    my $file = "$prefix$idx$content$extension";
 	    push_output( 'file',
 			 File::Spec->catfile( "$directory", "$file" ) );
-    	    output( "<?xml version='1.0'?>\n" );
+    	    output( "<?xml version='1.0' encoding='utf-8'?>\n" );
     	    output( "<!-- -*- DocBook -*- -->\n" );
 	}
 	output( $chapter{ $chapter_id } );
@@ -184,7 +184,7 @@ sub _output_end_book
 }
 sub _html_head
 {
-    output( "<?xml version='1.0'?>\n" );
+    output( "<?xml version='1.0' encoding='utf-8'?>\n" );
     output( "<!-- -*- DocBook -*- -->\n" );
     output( "<!DOCTYPE book PUBLIC \"-//OASIS//DTD DocBook XML V4.5//EN\"\n" );
     output( "    \"http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd\" [\n" );
@@ -199,7 +199,6 @@ sub _html_head
     $language_tag = 'en' if $language_tag eq undef;
 
     output( "<book lang=\"$language_tag\">\n" );
-    output( "<!-- This is UTF-8 encoded. -->\n" );
     output( "\n" );
     output( "<title>$title</title>\n" );
     output( "\n" );
